<!DOCTYPE html>
<html lang="en" class="ps-first-page-top">
<head>
{% block head_content %}
<meta charset="utf-8" />
<meta name="viewport" content="width=device-width, initial-scale=1" />
<meta name="generator" content="epijats" />
{% if has_math %}
{% if math_css_url %}
<link rel="stylesheet" href="{{math_css_url}}">
{% else %}
{% include "/dev/stderr/ math_css_url must be defined" %}
{% endif %}
{% endif %}
{% endblock head_content %}
</head>
<body>
{% block body_content %}
{% endblock body_content %}
</body>
</html>
